<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/classes.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('Ne pare rău, însă avem nevoie de wp-config-sample.php pentru a fi luat drept exemplu. Încărcați acel fișier din nou din arvhiva originală.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

if ( !is_writable(ABSPATH))
	wp_die("Ne pare rău, însă nu am drepturi de scriere în acel director. Este necesar să schimbați permisiunile de scriere pentru directorul WordPress, sau să creați wp-config.php manual.");

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>Fișierul &laquo;wp-config.php&raquo; deja există. Dacă credeți că ceva e greșit în acel fișier, ștergeți-l. Acum poate fi pornit <a href='install.php'>procesul de instalare</a>.</p>");

// Check if wp-config.php exists above the root directory
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>Fișierul &laquo;wp-config.php&raquo; deja există în directorul superior celui WordPress. Dacă credeți că ceva e greșit în acel fișier, ștergeți-l. Acum poate fi pornit <a href='install.php'>procesul de instalare</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Completarea parametrilor de configurare</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Bine ați venit. înainte de a începe, vor fi necesare informațiile despre baza de date. Acestea sunt detaliile ce va trebui să le știți înainte de a porni.</p>
<ol>
	<li>Numele bazei de date</li>
	<li>Numele utilizatorului bazei de date</li>
	<li>Parola utilizatorului bazei de date</li>
	<li>Adresa serverului bazei de date</li>
	<li>Prefixul tabelelor (dacă vor fi instalate mai multe instanțe WordPress folosind aceeași bază de date)</li>
</ol>
<p><strong>În cazul în care ceva nu a mers la crearea fișierului de configurare, nu e o problemă. Acest pas este dedicat doar populării fișierului de configurare. Puteți deschide <code>wp-config-sample.php</code> într-un editor de text, modifica fișierul, apoi salva sub noul nume de <code>wp-config.php</code>. </strong></p>
<p>Cel mai probabil, aceste detalii v-au fost oferite de serviciile de găzduire. Dacă nu le aveți, contactați un administrator a serviciilor de găzduire. Dacă totul e în ordine&hellip;</p>

<p class="step"><a href="setup-config.php?step=1" class="button">Să pornim!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Completați detaliile despre baza de date. Dacă nu sunteți sigur de aceste informații, luați legătura cu serviciile de găzduire. </p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Numele bazei de date</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Numele bazei de date unde doriți instalarea WordPress. </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Numele de utilizator</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>Numele de utilizator folosit la conectarea la baza de date</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Parola</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>&hellip;și parola utilizatorului MySQL.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Adresa serverului bazei de date</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>Cel mai probabil (99%) nu este necesară modificarea acestui parametru.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Prefixul tabelelor</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Dacă doriți mai multe instanțe WordPress folosind o singură bază de date, modificați acest parametru.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Trimite" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen(ABSPATH . 'wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod(ABSPATH . 'wp-config.php', 0666);

	display_header();
?>
<p>Felicitări, acest pas a trecut cu succes. WordPress acum se poate conecate la baza de date specificată. Dacă totul e în ordine, e timpul să&hellip;</p>

<p class="step"><a href="install.php" class="button">Pornim instalarea</a></p>
<?php
	break;
}
?>
</body>
</html>
